API Docs
========

Application and CLI factory
---------------------------

.. automodule:: invenio_base.app
   :members:

WSGI factory
------------

.. automodule:: invenio_base.wsgi
   :members:

Signals
-------

.. automodule:: invenio_base.signals
   :members:
